@@ -1,35 +1,56 @@
 from django.contrib import admin
 from django.contrib.admin import ModelAdmin
+from django.forms import ModelForm, Textarea
 from django.template.defaultfilters import truncatechars
 from django.urls import reverse
 from django.utils.html import format_html
 
-from .models import Post, Comment
+from published.admin import (PublishedAdmin, add_to_fieldsets,
+                             add_to_list_display, add_to_readonly_fields)
+
+from .models import Comment, Post
 
 
-class PostAdmin(ModelAdmin):
+class PostAdminForm(ModelForm):
+    class Meta:
+        widgets = {
+            'description': Textarea(attrs={'cols': 60, 'rows': 4}),
+        }
+
+
+class PostAdmin(PublishedAdmin):
+    form = PostAdminForm
     fieldsets = (
-        ('Content', {
-            'fields': ('title', 'tags', 'author', 'text')
+        ('Metadata', {
+            'fields': ('title', 'author', 'tags', 'description')
         }),
+        ('Content', {
+            'fields': ('text',)
+        }),
+        add_to_fieldsets(section=True, collapse=False),
         ('Image', {
             'fields': ('image',),
         }),
         ('Advanced options', {
+            'classes': ('collapse',),
             'fields': ('slug', 'allow_comments'),
         }),
     )
 
     prepopulated_fields = {"slug": ("title",)}
+    search_fields = ['title']
+    readonly_fields = add_to_readonly_fields()
     list_filter = ('created', 'tags', 'author')
-    list_display = ('title', 'tag_list', 'created', 'modified', 'author')
+    list_display = ['title', 'tag_list', 'created', 'modified', 'author'] + add_to_list_display()
 
-    def tag_list(self, obj):
-        return u", ".join(o.name for o in obj.tags.all())
+    @staticmethod
+    def tag_list(obj):
+        return ", ".join(o.name for o in obj.tags.all().order_by('name'))
 
 
 class CommentAdmin(ModelAdmin):
-    list_display = ('text_preview', 'post_link', 'author', 'created_date')
+    list_display = ('text_preview', 'post_link', 'author', 'created')
+    raw_id_fields = ('author',)
 
     def post_link(self, obj):
         return format_html('<a href="{}">{}</a>',
