@@ -7,14 +7,11 @@ from .models import Post
 
 
 @receiver(post_save, sender=Post)
-def warm_post_thumbnail_images(sender, instance, **kwargs):
+def warm_post_images(sender, instance, **kwargs):
     if instance.image:
         warmer = VersatileImageFieldWarmer(
             instance_or_queryset=instance,
-            rendition_key_set=[
-                ('banner', 'crop__350x200'),
-                ('thumb', 'crop__70x70')
-            ],
+            rendition_key_set='post_image',
             image_attr='image'
         )
         warmer.warm()
